@@ -15,16 +15,12 @@ on developer site.
 
 __author__ = """Elliot Palmer"""
 __email__ = 'elliot@ecoplumbers.com'
-__version__ = '0.1.0'
+__version__ = '0.3.2'
 
 # MODULES
 import requests
 import json
 
-# GLOBALS
-AUTH_ROOT = "https://auth.servicetitan.io"
-URL_ROOT = "https://api.servicetitan.io"
-
 from servicepytan.requests import Endpoint
 from servicepytan.reports import Report
 from servicepytan.data import DataService
